@@ -316,10 +316,16 @@ impl<'a> CertD<'a> {
             conn.trace(Some(trace));
         }
 
-        conn.execute_batch("PRAGMA secure_delete=true; \
-                            PRAGMA foreign_keys=true; \
-                            PRAGMA journal_mode=WAL; \
-                            ")?;
+        // for tests, deactivate the 'double-quoted string literal' feature
+        #[cfg(test)]
+        {
+            conn.set_db_config(rusqlite::config::DbConfig::SQLITE_DBCONFIG_DQS_DDL, false)?;
+            conn.set_db_config(rusqlite::config::DbConfig::SQLITE_DBCONFIG_DQS_DML, false)?;
+        }
+
+        conn.pragma_update_and_check(None, "secure_delete", true, |_| Ok(()))?;
+        conn.pragma_update(None, "foreign_keys", true)?;
+        conn.pragma_update_and_check(None, "journal_mode", "WAL", |_| Ok(()))?;
 
         let certd = Self {
             certd,
@@ -988,7 +994,7 @@ CREATE TABLE version (
 );
 
 -- Record the schema version.
-INSERT OR IGNORE INTO version VALUES (0, 1, \"sequoia cert cache v1\");
+INSERT OR IGNORE INTO version VALUES (0, 1, 'sequoia cert cache v1');
 
 -- Tag of the certd directory to quickly detect whether the db is stale.
 DROP TABLE IF EXISTS certd_tag;
