@@ -640,7 +640,7 @@ mod tests {
         // Create a certificate, and turn it into a verified
         // certificate.  This should create a few new cache entries.
         eprintln!("{}6. Generate a certificate", prefix);
-        let (alice, _rev) = CertBuilder::general_purpose(None, Some("xxx"))
+        let (alice, _rev) = CertBuilder::general_purpose(Some("xxx"))
             .generate()
             .expect("can generate certificate");
 
