@@ -24,7 +24,7 @@ use crate::store::UserIDQueryParams;
 
 use super::TRACE;
 
-const NP: &NullPolicy = &NullPolicy::new();
+const NP: &NullPolicy = unsafe { &NullPolicy::new() };
 
 // Reliable keyservers.
 /// keys.openpgp.org.
